namespace FitConnect.Interfaces;

public interface IFluentSender {
    public string PublicKey { get; }

    /// <summary>
    ///     Determines the destination id and configures the sender.
    /// </summary>
    /// <param name="leiaKey"></param>
    /// <param name="ags"></param>
    /// <param name="ars"></param>
    /// <param name="areaId"></param>
    /// <returns></returns>
    public IFluentSenderWithDestination FindDestinationId(string leiaKey, string? ags, string? ars,
        string? areaId);

    /// <summary>
    ///     Configures the client for the given destination and loads the public key
    /// </summary>
    /// <param name="destinationId">
    ///     unique identifier of the clients destination
    ///     <para>eg: 00000000-0000-0000-0000-000000000000</para>
    /// </param>
    /// <returns>the upload step for attachments</returns>
    public IFluentSenderWithDestination WithDestination(string destinationId);


    /// <summary>
    /// </summary>
    /// <param name="data">The data for the submission in a json string</param>
    /// <exception cref="ArgumentException">If the data is not a valid json string</exception>
    /// <returns></returns>
    public IFluentSenderWithData WithData(string data);
}
