using FitConnect.Models;
using FitConnect.Services.Models.v1;

namespace FitConnect.Interfaces;

public interface IFluentSubscriber {
    /// <summary>
    ///     Loads a list of available Submissions that were submitted to the subscriber.
    /// </summary>
    /// <param name="destinationId">unique identifier of the destination</param>
    /// <param name="offset">the offset of the list of submissions</param>
    /// <param name="limit">the limit of the list of submissions</param>
    /// <returns>List of available submissions for pickup</returns>
    public IEnumerable<SubmissionForPickupDto> GetAvailableSubmissions(string? destinationId = null,
        int offset = 0, int limit = 100);

    /// <summary>
    ///     Loads a single Submission by id.
    /// </summary>
    /// <param name="submissionId">unique identifier of a <see cref="Submission" /></param>
    /// <returns></returns>
    public IFluentSubscriberWithSubmission RequestSubmission(string submissionId);

    /// <summary>
    ///     Accept submission and delete it from the server
    /// </summary>
    /// <param name="caseId">Case Id</param>
    public void AcceptSubmission(string caseId, string submissionId, string destinationId);

    public void RejectSubmission(string caseId, string submissionId, string destinationId);
    public void ForwardSubmission(string caseId, string submissionId, string destinationId);

    public void CompleteSubmission(string caseId, string submissionId, string destinationId,
        FinishSubmissionStatus status);
}
